@@ -32,7 +32,7 @@ class ConfigFileObj(CodeGenerator):
         if not isinstance(self.files, list):
             raise TypeError(f"Wrong format used in config file {self.config_path}")
         for file in self.files:
-            file = os.path.expandvars(file.strip('" '))
+            file = os.path.expandvars(str(file).strip('" '))
             if not os.path.isabs(file):
                 if self.config_path is not None:
                     path_suffix = file.replace('\\', '/').replace('/', os.sep).split(os.sep)
@@ -108,4 +108,4 @@ class MEMFile(Sources):
 
 class BDFile(Sources):
     def __init__(self, files: str, fileset=r"default", config_path=None):
-        super().__init__(files=[files], fileset=fileset, config_path=config_path)
\ No newline at end of file
+        super().__init__(files=[files], fileset=fileset, config_path=config_path)
